import asyncio
import os

import aiohttp
import requests
import google.generativeai as genai

import uuid



class VideoAnalyzer:
    def __init__(self, api_key):
        """初始化类，配置 API 密钥和视频路径"""
        genai.configure(api_key=api_key)
        self.video_file = None

    async def process_and_delete_file(self, file_path):
        """删除文件"""
        try:
            print(f"正在处理文件: {file_path}" )
            os.remove( file_path )
            print( f"文件已删除: {file_path}" )
        except Exception as e:
            print( f"处理或删除文件时发生错误: {str( e )}" )

    async def download_video(self, video_url,  save_directory='/root/google_ai_studio/path'):
    # async def download_video(self, video_url, save_directory='/Users/tzld/Desktop/google_ai_studio/path'):

        """从给定的视频链接下载视频并保存到指定路径"""
        try:
            # 发送 GET 请求获取视频内容
            random_filename = f"{uuid.uuid4()}.mp4"
            save_path = os.path.join(save_directory, random_filename)
            async with aiohttp.ClientSession() as session:
                async with session.get( video_url ) as response:
                    response.raise_for_status()  # 检查请求是否成功
                    with open( save_path, 'wb' ) as video_file:
                        while True:
                            chunk = await response.content.read( 1024 * 1024 )  # 每次读取 1MB
                            if not chunk:
                                break
                            video_file.write( chunk )

                print( f"视频已成功下载并保存到: {save_path}" )
                return save_path
        except requests.exceptions.RequestException as e:
            print( f"下载视频时出现错误: {e}" )
            return None

    async def upload_video(self, save_path, mime_type = None):
        """上传视频文件并获取视频文件对象"""
        self.video_file = genai.upload_file(save_path, mime_type=mime_type)
        await self._wait_for_processing()

    async def _wait_for_processing(self):
        """等待视频文件处理完成"""
        while self.video_file.state.name == 'PROCESSING':
            print( '等待视频处理完成...' )
            await asyncio.sleep(2)  # 使用异步睡眠代替阻塞睡眠
            self.video_file = genai.get_file( self.video_file.name )
        print( f'视频处理完成: {self.video_file.uri}' )

    async def create_cache(self):
        generation_config = {
            "temperature": 1,
            "top_p": 0.95,
            "top_k": 64,
            "max_output_tokens": 8192,
            "response_mime_type": "application/json"
        }
        """创建缓存内容，并返回生成模型"""
        # 创建生成模型，使用 gemini-1.5-flash 模型
        model = genai.GenerativeModel(
            model_name="gemini-1.5-flash",
            generation_config=generation_config,

        )

        return model
    async def analyze_video(self, model, questions, sample_data):
            chat_session = model.start_chat(history=[])
            message_content = {
                "parts": [
                    self.video_file,
                    str(questions) +
                    "输出返回格式样例:\n" + str(sample_data)

                ]
            }
            response = chat_session.send_message( message_content )
            return response

async def main(video_path):
    """主函数，执行视频上传、缓存创建、问题生成"""
    try:
        api_key = 'AIzaSyC-IxUvJhbiKWA7uN1RTtVbOjt3pj_-Apc'

        # 初始化视频分析类
        analyzer = VideoAnalyzer(api_key )
        save_path = await analyzer.download_video(video_path)
        if not save_path:
            if os.path.exists( save_path ):
                os.remove( save_path )
                print( f"文件已删除: {save_path}" )
            print("视频下载失败")
            return "视频下载失败"
        # 上传并处理视频
        await analyzer.upload_video(save_path)

        # 创建缓存模型
        model =await analyzer.create_cache()
        sample_data = {
            "一、基础信息": {
                "视觉/音乐/文字": "",
                "内容选题": "",
                "视频主题": ""
            },
            "二、主体和场景": {
                "视频主体": "",
                "视频场景": []
            },
            "三、情感与风格": {},
            "四、视频传播性与观众": {
                "片尾引导": {},
                "传播性判断": "",
                "观众画像": {}
            },
            "五、音画细节": {
                "音频细节": {},
                "视频水印": {},
                "视频字幕": {},
                "视频口播": ""
            },
            "六、人物与场景": {
                "知名人物": {},
                "人物年龄段": "",
                "场景描述": []
            },
            "七、时效性与分类": {
                "时效性": {},
                "视频一级分类": "",
                "二级分类": ""
            }
        }

        # 视频分析问题
        video_analysis_questions = "你是一个专业的视频分析师，我将给你一个视频，请你对视频进行理解，回答下面的问题。\n一、基础信息：\n1视觉/音乐/文字：请从视频中的视觉、音乐、文字这三个维度信息做分析比较，哪个维度的信息是该视频中最重要的，可能成为该视频的要点驱动力？你只要回答视觉/音乐/文字三者其一即可。\n2内容选题：如果需要从视频中提取一个内容选题，你觉得应该是什么？请注意：选题应该体现视频的关键点，亮点，爆点，选题不能超过8个字。\n3视频主题：描述视频的整体主题。\n二、主体和场景：\n1视频主体：视频中的核心人物或物体，有几个？分别是什么？\n2视频场景：视频属于什么场景？场景可以有多个，每个不超过6个字。\n三、情感与风格：\n1情感倾向：视频传递的情感是积极、消极还是中立或其他？\n2视频风格：判断视频的风格类型（如严肃、轻松、幽默等）。\n四、视频传播性与观众：\n1片尾引导\n•视频片尾是否有引导观众分享？\n•引导时长？\n•引导强度如何？\n2传播性判断：基于中国中老年微信用户，判断该视频的传播性并说明依据。\n3观众画像：\n•推测观众的年龄。\n•推测观众的性别。\n•推测观众的地域。\n五、音画细节：\n1音频细节\n•视频中的音频信息，是否有歌曲？\n•视频中的音频信息，歌曲名是什么？\n•视频中的音色音色是怎样的？\n2视频水印\n•是否有产品名的水印？\n•水印是否涉及产品名称是什么？\n3视频字幕\n•是否有字幕？\n•字幕的颜色？\n•字幕的字号？\n•字幕的位置如何？\n4视频口播：提供视频中出现的准确且完整的口播内容。\n六、人物与场景：\n1知名人物\n•视频或音频中是否出现知名人物？\n•视频或音频中是否出现知名人物是谁？\n2人物年龄段：视频中人物的年龄段（如中青年男、中青年女等）。\n3场景描述：视频和声音中涉及的场景描述。\n七、时效性与分类：\n1时效性：\n•适用时效日。\n•适用时效早中晚。\n2视频一级分类：判断视频分别属于下面的哪种一级分类，并输出准确完整的一级品类_分类名称：\n1. 一级品类_音乐\n2. 一级品类_剧情 / 剧情演绎\n3. 一级品类_二次元\n4. 一级品类_游戏\n5. 一级品类_公益\n6. 一级品类_随拍 / 颜值\n7. 一级品类_舞蹈\n8. 一级品类_动物 / 萌宠\n9. 一级品类_三农\n10. 一级品类_科技 / 科技数码\n11. 一级品类_财经\n12. 一级品类_母婴 / 母婴亲子\n13. 一级品类_法律 / 人文社科\n14. 一级品类_科普 / 人文社科\n15. 一级品类_情感 / 情感心理\n16. 一级品类_职场 / 人文社科\n17. 一级品类_教育 / 教育培训\n18. 一级品类_摄影摄像\n19. 一级品类_艺术 / 才艺技能\n20. 一级品类_美食\n21. 一级品类_旅行 / 旅游\n22. 一级品类_地域本地\n23. 一级品类_时尚 / 时尚 / 美妆\n24. 一级品类_文化 / 人文社科\n25. 一级品类_搞笑 / 休闲娱乐\n26. 一级品类_明星 / 名人\n27. 一级品类_综艺\n28. 一级品类_影视综艺\n29. 一级品类_电影\n30. 一级品类_电视剧\n31. 一级品类_汽车\n32. 一级品类_体育 / 运动\n33. 一级品类_医疗健康 / 长寿 / 健身\n34. 一级品类_生活记录 / 生活\n35. 一级品类_生活家居 / 家居家装\n36. 一级品类_时政社会\n37. 一级品类_奇人异象\n38. 一级品类_历史\n39. 一级品类_军事\n40. 一级品类_宗教\n41. 一级品类_短剧\n42. 一级品类_收藏品\n3视频二级分类：判断视频分别属于下面的哪种二级分类，并输出准确完整的品类-分类名称：\n品类-祝福音乐：以送祝福为主题的音乐，通常用于庆祝生日、节日、婚礼等场合。\n2. 品类-人生感悟音乐：反映人生哲理和感悟的音乐，表达对生活、时间、命运的思考。\n3. 品类-民族异域音乐：表现不同国家和民族文化风情的音乐，具有地方特色和异域风情。\n4. 品类-亲情音乐：以家庭和亲情为主题的音乐，表达对家人的关怀与爱。\n5. 品类-红歌老歌：指红色革命歌曲及经典老歌，反映历史、社会或革命精神的音乐作品。\n6. 品类-音乐知识：介绍音乐理论、历史、风格以及相关知识的视频。\n7. 品类-正能量剧情：充满正能量的剧情短片，鼓励积极向上的生活态度。\n8. 品类-对口型表演：演员或普通人模仿歌曲、台词的对口型表演视频，常以搞笑为主。\n9. 品类-快闪：指在公共场所突然进行的集体表演，通常是舞蹈或音乐表演，具有瞬间性和惊喜感。\n10. 品类-拟真游戏：模仿现实世界的游戏，如驾驶、建筑、农业等，让玩家体验真实情境。\n11. 品类-麻将：以麻将为主题的视频，可能包含麻将技巧、教学或比赛。\n12. 品类-棋牌：与棋类、牌类相关的视频，包括游戏演示、技巧分享等。\n13. 品类-老年审美美女：符合老年人审美标准的女性展示内容，可能涉及穿搭、仪表等。\n14. 品类-老年审美帅哥：展现符合老年人审美标准的男性，通常以绅士风格和成熟气质为主。\n15. 品类-红歌老歌舞蹈：伴随红歌和老歌的舞蹈表演，常见于集体活动或文艺演出。\n16. 品类-广场舞：中老年群体在广场等公开场合跳的集体舞蹈，常见于健身或娱乐活动。\n17. 品类-舞蹈教程：教授各种舞蹈动作和技巧的教学视频。\n18. 品类-宠物日常：记录宠物日常生活的短视频，展示其可爱的瞬间或有趣的行为。\n19. 品类-动物表演：展示动物参与的表演或训练成果，如马戏、宠物秀等。\n20. 品类-生动物：记录生物或野生动物的生活，通常包括动物行为、栖息地等自然场景。\n21. 品类-农村生活：展示农村地区的日常生活，往往包括农业劳动、乡村风景等。\n22. 品类-农业技术：讲解现代农业技术、种植养殖技巧的科普内容。\n23. 品类-老年相关科技：专为老年人设计的科技产品或服务，如智能设备、健康监测工具等。\n24. 品类-未来科幻：以未来世界、科幻场景为背景的内容，展示未来技术、太空探索等。\n25. 品类-国家科技力量：展示国家在科技领域取得的成就或重要技术进展。\n26. 品类-保险：围绕保险知识、产品介绍、保险购买建议等内容的视频。\n27. 品类-理财：讲解理财知识、投资策略及个人财务管理的方法。\n28. 品类-亲子日常：记录亲子互动、家庭日常生活的视频，常有温馨、教育性质。\n29. 品类-K12教育：涵盖从幼儿园到12年级的教育内容，包括课业辅导、学习技巧等。\n30. 品类-老年相关法律科普：专为老年群体提供的法律知识科普，如财产继承、养老金等。\n31. 品类-知识科普：涉及各个领域的知识普及视频，涵盖科学、历史、文化等多方面。\n32. 品类-生活技巧科普：分享实用的生活小窍门，如家务技巧、维修小贴士等。\n33. 品类-怀念时光：带有怀旧情感的视频，通常回顾过去的生活、音乐、电影等。\n34. 品类-人生忠告：分享人生经验、哲理或建议的内容，具有启发性和指导性。\n35. 品类-迷信祝福：包含传统民间习俗中的迷信元素，如求平安、避灾祈福的视频。\n36. 品类-节日祝福：在节日期间分享祝福的视频，通常用于庆祝节日或传递问候。\n37. 品类-早中晚好：问候类视频，早晨、午间或晚间送出祝福或温馨提示。\n38. 品类-退休前：针对即将退休的人群，提供退休前的准备建议或心态调整。\n39. 品类-退休后：讨论退休后的生活方式、活动或心理调节的内容。\n40. 品类-益智解密：通过解谜游戏或益智问题，激发思考和智力的内容。\n41. 品类-老年教育：为老年人提供的继续教育内容，包括兴趣班、技能学习等。\n42. 品类-风景实拍：展示自然风景的实拍视频，通常包括山川河流、海滩森林等美景。\n43. 品类-动植物实拍：直接记录动植物的生活状态、自然环境的实拍内容。\n44. 品类-人像模特实拍：展示模特的时尚摄影或造型展示，关注人像艺术。\n45. 品类-摄影教学：讲授摄影技巧、拍摄理念或后期处理的教学内容。\n46. 品类-名画赏析：分析和解读名画的艺术价值、历史背景和技术细节。\n47. 品类-杂技柔术：展示杂技、柔术等特技表演，通常为娱乐性和观赏性较强的节目。\n48. 品类-魔术：展示各种魔术表演，通常包括戏法和观众互动。\n49. 品类-魔术特效：展示运用特效技术的魔术表演，结合视觉效果增强表演效果。\n50. 品类-书法：介绍书法艺术、技巧与文化背景的内容，可能包括书法教学。\n51. 品类-绘画：教授绘画技巧、风格和媒介的内容，适合各个水平的艺术爱好者。\n52. 品类-木工：介绍木工技艺、工具使用及制作技巧的视频。\n53. 品类-口技：表演口技的内容，通过声音模拟自然界或乐器声，通常以娱乐为主。\n54. 品类-大型集体艺术：展示大型团体艺术表演的内容，如合唱、舞蹈等集体表演。\n55. 品类-戏曲戏剧：包含戏曲和戏剧的表演视频，展示传统文化艺术形式。\n56. 品类-二人转：以二人转为主题的表演，通常为地方戏曲，内容风趣幽默。\n57. 品类-其他才艺：包含多种才艺表演，如歌唱、乐器演奏等，展示个人才华。\n58. 品类-美食测评：对美食进行评测、评分的视频，通常包括外卖、餐馆等。\n59. 品类-美食教程：教授美食制作过程、技巧及食材选择的内容，适合家庭烹饪爱好者。\n60. 品类-吃播探店：记录吃播者探店、品尝美食的过程，通常包含个人点评。\n61. 品类-旅行记录：记录旅行中的见闻、景点介绍及个人感受，分享旅游体验。\n62. 品类-旅行攻略：提供旅行目的地的攻略，包括交通、住宿、美食推荐等。\n63. 品类-省份城市亮点：介绍各省份和城市的特色、景点和文化亮点的视频。\n64. 品类-本地新闻：报道当地的新闻事件、社会动态，关注民生问题。\n65. 品类-本地生活：涉及当地生活的内容，介绍社区活动、居民生活等。\n66. 品类-老年时尚：展示适合老年人的时尚穿搭及生活方式。\n67. 品类-美妆护肤穿搭：涉及美妆、护肤、穿搭技巧和产品推荐的内容。\n68. 品类-传统文化：介绍传统文化的习俗、节日、艺术等，传播文化知识。\n69. 品类-国际文化：涉及国际文化交流的内容，展示不同文化的碰撞与融合。\n70. 品类-搞笑瞬间合集：收集搞笑瞬间的短视频，通常是生活中的趣事或搞笑片段。\n71. 品类-搞笑段子：包含幽默搞笑的段子，通常通过小品、表演等形式呈现。\n72. 品类-历史名人：介绍历史名人的生平、成就和影响的内容，常为传记类视频。\n73. 品类-当代正能量人物：关注当代具有正能量的人物，展示其故事与成就。\n74. 品类-老明星：介绍老一代明星的演艺生涯或他们的最新动态。\n75. 品类-老年人上综艺：展示老年人参加综艺节目的场景，通常以互动、才艺为主。\n76. 品类-老年关心纪录片：以老年生活或老年相关议题为主题的纪录片。\n77. 品类-老综艺影像：经典综艺节目回顾或精选片段。\n78. 品类-电影切片：从电影中剪辑出的精彩片段，用于回顾或分享电影亮点。\n79. 品类-电影解说：讲解电影情节、分析影片内涵或推荐电影。\n80. 品类-电视剧切片：从电视剧中选取的片段，展示关键剧情或人物互动。\n81. 品类-电视剧解说：对电视剧剧情、角色或情节发展进行分析和评论。\n82. 品类-中国队比赛：展示中国体育队伍在各类赛事中的比赛视频。\n83. 品类-老年运动：介绍适合老年人的运动项目或健身技巧，保持健康体魄。\n84. 品类-健康知识：分享与健康相关的知识，涵盖饮食、锻炼、心理健康等。\n85. 品类-长寿知识：围绕如何延年益寿的主题，介绍生活习惯、饮食和保健方法。\n86. 品类-饮食健康：提供关于健康饮食的建议，帮助观众养成良好的饮食习惯。\n87. 品类-健身操：适合各类人群的健身操教学视频，增强体质和柔韧性。\n88. 品类-老年生活：分享老年群体的日常生活、娱乐活动及养生方法。\n89. 品类-生活小妙招：提供各种实用的生活小技巧，提升日常生活的便利性。\n90. 品类-园艺花艺：教授园艺知识和花卉栽培技巧，适合家庭花园爱好者。\n91. 品类-民生政策：涉及与百姓生活息息相关的政策解读，如养老、医保等。\n92. 品类-流行病疫情：关于流行病传播及疫情防控的信息和科普。\n93. 品类-社会风气：反映当下社会现象、风气的评论或分析。\n94. 品类-食品安全：分享食品安全知识，普及健康饮食和防范食品危害的方法。\n95. 品类-贪污腐败：揭露或评论贪污腐败现象的视频，呼吁廉政。\n96. 品类-人财诈骗：揭示或分析常见的诈骗手段，提醒公众防范。\n97. 品类-核污染：关于核污染问题的讨论，介绍其影响及防护措施。\n98. 品类-惠民新闻：展示与民生福利相关的政策新闻和实际落实情况。\n99. 品类-天气变化：提供关于天气变化的预报及分析，特别是气候问题的讨论。\n100. 品类-国家力量：展示国家在各个领域的强大实力，如军事、科技、经济等。\n101. 品类-国际时政：关于全球时事和国际政治局势的报道和评论。\n102. 品类-他国政策：介绍和分析其他国家的政策、社会变革或政治动态。\n103. 品类-惊奇事件：分享世界各地的奇闻异事，充满趣味和惊叹。\n104. 品类-罕见画面：展示罕见、特别或极具视觉冲击力的画面或事件。\n105. 品类-中国战争史：回顾中国历史上重要的战争及其影响的视频。\n106. 品类-中国党史：介绍中国共产党的历史发展及其关键事件。\n107. 品类-中国历史影像：展现中国历史中的经典影像资料，如旧照片、历史视频。\n108. 品类-国际军事：涉及各国军事力量、国际军事动态的新闻和分析。\n109. 品类-国内军事：展示中国国内军事力量的发展及重大军事事件。\n110. 品类-国家统一：关于中国国家统一进程、两岸关系等相关议题的视频。",

        # video_analysis_questions = "一、基础信息：\n" \
        #                            "1.视觉/音乐/文字： 请从视频中的视觉、音乐、文字这三个维度信息做分析比较，哪个维度的信息是该视频中最重要的，可能成为该视频的要点驱动力？你只要回答 视觉/音乐/文字 三者其一即可。\n" \
        #                            "2.内容选题： 如果需要从视频中提取一个内容选题，你觉得应该是什么？请注意：选题应该体现视频的关键点，亮点，爆点，选题不能超过8个字。\n" \
        #                            "3.视频主题：描述视频的整体主题。\n " \
        #                            "二、主体和场景：\n" \
        #                            "1.视频主体：视频中的核心人物或物体，有几个？分别是什么？\n" \
        #                            "2.视频场景：视频属于什么场景？场景可以有多个，每个不超过6个字\n" \
        #                            "三、情感与风格：\n" \
        #                            "1.情感倾向：视频传递的情感是积极、消极还是中立或其他？\n" \
        #                            "2.视频风格：判断视频的风格类型（如严肃、轻松、幽默等）。\n四、视频传播性与观众：\n" \
        #                            "1.片尾引导\n" \
        #                            "视频片尾是否有引导观众分享？\n" \
        #                            "引导时长？\n" \
        #                            "引导强度如何？\n" \
        #                            "2.传播性判断：基于中国中老年微信用户，判断该视频的传播性并说明依据。\n" \
        #                            "3.观众画像：\n" \
        #                            "推测观众的年龄\n" \
        #                            "推测观众的性别\n" \
        #                            "推测观众的地域\n" \
        #                            "五、音画细节：\n" \
        #                            "1.音频细节\n" \
        #                            "视频中的音频信息，是否有歌曲？\n" \
        #                            "视频中的音频信息，歌曲名是什么？\n" \
        #                            "视频中的音色音色是怎样的？\n" \
        #                            "2.视频水印\n" \
        #                            "是否有产品名的水印？\n" \
        #                            "水印是否涉及产品名称是什么？\n" \
        #                            "3.视频字幕\n" \
        #                            "是否有字幕？\n" \
        #                            "字幕的颜色？\n" \
        #                            "字幕的字号？\n" \
        #                            "字幕的位置如何？\n" \
        #                            "4. 视频口播：提供视频中出现的准确且完整的口播内容。\n" \
        #                            "六、人物与场景：\n" \
        #                            "1.知名人物\n" \
        #                            "视频或音频中是否出现知名人物？\n" \
        #                            "视频或音频中是否出现知名人物是谁？\n" \
        #                            "2.人物年龄段：视频中人物的年龄段（如中青年男、中青年女等）。\n" \
        #                            "3.场景描述：视频和声音中涉及的场景描述。\n" \
        #                            "七、时效性与分类：\n" \
        #                            "1.时效性：\n" \
        #                            "适用时效日\n" \
        #                            "适用时效早中晚\n" \
        #                            "2.视频一级分类：判断视频分别属于下面的哪种一级分类，并输出准确完整的一级品类_分类名称:\n" \
        #                            "一级分类范围为：\n" \
        #                            "一级品类_音乐\n" \
        #                            "一级品类_剧情 / 剧情演绎\n" \
        #                            "一级品类_二次元\n" \
        #                            "一级品类_游戏\n" \
        #                            "一级品类_公益\n" \
        #                            "一级品类_随拍 / 颜值\n" \
        #                            "一级品类_舞蹈\n" \
        #                            "一级品类_动物 / 萌宠\n" \
        #                            "一级品类_三农\n" \
        #                            "一级品类_科技 / 科技数码\n" \
        #                            "一级品类_财经\n" \
        #                            "一级品类_母婴 / 母婴亲子\n" \
        #                            "一级品类_法律 / 人文社科\n" \
        #                            "一级品类_科普 / 人文社科\n" \
        #                            "一级品类_情感 / 情感心理\n" \
        #                            "一级品类_职场 / 人文社科\n" \
        #                            "一级品类_教育 / 教育培训\n" \
        #                            "一级品类_摄影摄像\n" \
        #                            "一级品类_艺术 / 才艺技能\n" \
        #                            "一级品类_美食\n" \
        #                            "一级品类_旅行 / 旅游\n" \
        #                            "一级品类_地域本地\n" \
        #                            "一级品类_时尚 / 时尚 / 美妆\n" \
        #                            "一级品类_文化 / 人文社科\n" \
        #                            "一级品类_搞笑 / 休闲娱乐\n" \
        #                            "一级品类_明星 / 名人\n" \
        #                            "一级品类_综艺\n" \
        #                            "一级品类_影视综艺\n" \
        #                            "一级品类_电影\n" \
        #                            "一级品类_影视综艺\n" \
        #                            "一级品类_电视剧\n" \
        #                            "一级品类_影视综艺\n" \
        #                            "一级品类_汽车\n" \
        #                            "一级品类_体育 / 运动\n" \
        #                            "一级品类_医疗健康 / 长寿 / 健身\n" \
        #                            "一级品类_生活记录 / 生活\n" \
        #                            "一级品类_生活家居 / 家居家装\n" \
        #                            "一级品类_时政社会\n" \
        #                            "一级品类_奇人异象\n" \
        #                            "一级品类_历史\n" \
        #                            "一级品类_军事\n" \
        #                            "一级品类_宗教\n" \
        #                            "一级品类_短剧\n" \
        #                            "一级品类_收藏品\n" \
        #                            "3.二级分类： 判断视频分别属于下面的哪种二级分类，并输出准确完整的品类-分类名称\n" \
        #                            "二级分类范围为：\n" \
        #                            "品类-祝福音乐\n" \
        #                            "品类-人生感悟音乐\n" \
        #                            "品类-民族异域音乐\n" \
        #                            "品类-亲情音乐\n" \
        #                            "品类-红歌老歌\n" \
        #                            "品类-音乐知识\n" \
        #                            "品类-正能量剧情\n" \
        #                            "品类-对口型表演\n" \
        #                            "品类-快闪\n" \
        #                            "品类-拟真游戏\n" \
        #                            "品类-麻将\n" \
        #                            "品类-棋牌\n" \
        #                            "品类-老年审美美女\n" \
        #                            "品类-老年审美帅哥\n" \
        #                            "品类-红歌老歌舞蹈\n" \
        #                            "品类-广场舞\n" \
        #                            "品类-舞蹈教程\n" \
        #                            "品类-宠物日常\n" \
        #                            "品类-动物表演\n" \
        #                            "品类-生动物\n" \
        #                            "品类-农村生活\n" \
        #                            "品类-农业技术\n" \
        #                            "品类-老年相关科技\n" \
        #                            "品类-未来科幻\n" \
        #                            "品类-国家科技力量\n" \
        #                            "品类-保险\n" \
        #                            "品类-理财\n" \
        #                            "品类-亲子日常\n" \
        #                            "品类-K12教育\n" \
        #                            "品类-老年相关法律科普\n" \
        #                            "品类-知识科普\n" \
        #                            "品类-生活技巧科普\n" \
        #                            "品类-怀念时光\n" \
        #                            "品类-人生忠告\n" \
        #                            "品类-迷信祝福\n" \
        #                            "品类-节日祝福\n" \
        #                            "品类-早中晚好\n" \
        #                            "品类-退休前\n" \
        #                            "品类-退休后\n" \
        #                            "品类-益智解密\n" \
        #                            "品类-老年教育\n" \
        #                            "品类-风景实拍\n" \
        #                            "品类-动植物实拍\n" \
        #                            "品类-人像模特实拍\n" \
        #                            "品类-摄影教学\n" \
        #                            "品类-名画赏析\n" \
        #                            "品类-杂技柔术\n" \
        #                            "品类-魔术\n" \
        #                            "品类-魔术特效\n" \
        #                            "品类-书法\n" \
        #                            "品类-绘画\n" \
        #                            "品类-木工\n" \
        #                            "品类-口技\n" \
        #                            "品类-大型集体艺术\n" \
        #                            "品类-戏曲戏剧\n" \
        #                            "品类-二人转\n" \
        #                            "品类-其他才艺\n" \
        #                            "品类-美食测评\n" \
        #                            "品类-美食教程\n" \
        #                            "品类-吃播探店\n" \
        #                            "品类-旅行记录\n" \
        #                            "品类-旅行攻略\n" \
        #                            "品类-省份城市亮点\n" \
        #                            "品类-本地新闻\n" \
        #                            "品类-本地生活\n" \
        #                            "品类-老年时尚\n" \
        #                            "品类-美妆护肤穿搭\n" \
        #                            "品类-传统文化\n" \
        #                            "品类-国际文化\n" \
        #                            "品类-搞笑瞬间合集\n" \
        #                            "品类-搞笑段子\n" \
        #                            "品类-历史名人\n" \
        #                            "品类-当代正能量人物\n" \
        #                            "品类-老明星\n" \
        #                            "品类-老年人上综艺\n" \
        #                            "品类-老年关心纪录片\n" \
        #                            "品类-老综艺影像\n" \
        #                            "品类-电影切片\n" \
        #                            "品类-电影解说\n" \
        #                            "品类-电视剧切片\n" \
        #                            "品类-电视剧解说\n" \
        #                            "品类-中国队比赛\n" \
        #                            "品类-老年运动\n" \
        #                            "品类-健康知识\n" \
        #                            "品类-长寿知识\n" \
        #                            "品类-饮食健康\n" \
        #                            "品类-健身操\n" \
        #                            "品类-老年生活\n" \
        #                            "品类-生活小妙招\n" \
        #                            "品类-园艺花艺\n" \
        #                            "品类-民生政策\n" \
        #                            "品类-流行病疫情\n" \
        #                            "品类-社会风气\n" \
        #                            "品类-食品安全\n" \
        #                            "品类-贪污腐败\n" \
        #                            "品类-人财诈骗\n" \
        #                            "品类-核污染\n" \
        #                            "品类-惠民新闻\n" \
        #                            "品类-天气变化\n" \
        #                            "品类-国家力量\n" \
        #                            "品类-国际时政\n" \
        #                            "品类-他国政策\n" \
        #                            "品类-惊奇事件\n" \
        #                            "品类-罕见画面\n" \
        #                            "品类-中国战争史\n" \
        #                            "品类-中国党史\n" \
        #                            "品类-中国历史影像\n" \
        #                            "品类-国际军事\n" \
        #                            "品类-国内军事\n" \
        #                            "品类-国家统一\n" \

        # 分析视频并打印结果
        response =await analyzer.analyze_video( model, video_analysis_questions, sample_data )
        print( response.usage_metadata )
        print(response.text)
        if os.path.exists( save_path ):
            os.remove( save_path )
            print( f"文件已删除: {save_path}" )
        return response.text
    except Exception as e:
        return f"视频分析处理失败:{e}"


if __name__ == "__main__":
    proxy_url = 'http://127.0.0.1:1081'
    os.environ["http_proxy"] = proxy_url
    os.environ["https_proxy"] = proxy_url
    # video_path = 'http://temp.yishihui.com/longvideo/transcode/video/vpc/20240926/66510681PACx7zsp2wDBHJlicE.mp4'
    video_path = 'http://temp.yishihui.com/longvideo/transcode/video/vpc/20240605/68754804SJz5E9JNe5hAdSkRwF.mp4'
    asyncio.run(main(video_path))
